@@ -26,12 +26,17 @@ setConstructorS3("UnitAnnotationDataFile", function(...) {
   extend(Interface(), "UnitAnnotationDataFile");
 })
 
-setMethodS3("getChipType", "UnitAnnotationDataFile", abstract=TRUE);
+setMethodS3("getChipType", "UnitAnnotationDataFile", function(...) {
+  NextMethod("getChipType", ...);
+})
 
-setMethodS3("getPlatform", "UnitAnnotationDataFile", abstract=TRUE);
-
-setMethodS3("nbrOfUnits", "UnitAnnotationDataFile", abstract=TRUE);
+setMethodS3("getPlatform", "UnitAnnotationDataFile", function(...) {
+  NextMethod("getPlatform", ...);
+})
 
+setMethodS3("nbrOfUnits", "UnitAnnotationDataFile", function(...) {
+  NextMethod("nbrOfUnits", ...);
+})
 
 setMethodS3("byChipType", "UnitAnnotationDataFile", function(static, chipType, tags=NULL, nbrOfUnits=NULL, ..., verbose=FALSE) {
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -135,8 +140,29 @@ setMethodS3("getAromaUgpFile", "UnitAnnotationDataFile", function(this, ..., val
 
  
 
+setMethodS3("getAromaUflFile", "UnitAnnotationDataFile", function(this, ..., validate=FALSE, force=FALSE) {
+  ufl <- this$.ufl;
+  if (force || is.null(ufl)) {
+    chipType <- getChipType(this, ...);
+    ufl <- AromaUflFile$byChipType(chipType, nbrOfUnits=nbrOfUnits(this), validate=validate);
+    # Sanity check
+    if (nbrOfUnits(ufl) != nbrOfUnits(this)) {
+      throw("The number of units in located UFL file ('", getPathname(ufl), "') is not compatible with the data file ('", getPathname(this), "'): ", nbrOfUnits(ufl), " != ", nbrOfUnits(this));
+    }
+    this$.ufl <- ufl;
+  }
+  ufl;
+}) 
+
+ 
+
 ############################################################################
 # HISTORY:
+# 2009-11-20
+# o Now the "abstract" methods of the interface call NextMethod() instead,
+#   which will give an error if nothing is defined.
+# 2009-11-11
+# o Added getAromaUflFile() to UnitAnnotationDataFile.
 # 2009-07-08
 # o Extracted methods from the UnitNamesFile interface class.
 # o Created from UnitNamesFile.R.
